@@ -86,7 +86,7 @@
 #define KSERVICE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KSERVICE_NO_DEPRECATED
-#  define KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54f00
+#  define KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KSERVICE_NO_DEPRECATED_WARNINGS
 #  define KSERVICE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KSERVICE_DEPRECATED_WARNINGS_SINCE KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KSERVICE_DEPRECATED_WARNINGS_SINCE 0x54f00
+#    define KSERVICE_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -163,8 +163,33 @@
 #else
 #  define KSERVICE_DEPRECATED_VERSION_5_79(text)
 #endif
+
+#if KSERVICE_DEPRECATED_WARNINGS_SINCE >= 0x55000
+#  define KSERVICE_DEPRECATED_VERSION_5_80(text) KSERVICE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KSERVICE_DEPRECATED_VERSION_5_80(text)
+#endif
+
+#if KSERVICE_DEPRECATED_WARNINGS_SINCE >= 0x55100
+#  define KSERVICE_DEPRECATED_VERSION_5_81(text) KSERVICE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KSERVICE_DEPRECATED_VERSION_5_81(text)
+#endif
+
+#if KSERVICE_DEPRECATED_WARNINGS_SINCE >= 0x55200
+#  define KSERVICE_DEPRECATED_VERSION_5_82(text) KSERVICE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KSERVICE_DEPRECATED_VERSION_5_82(text)
+#endif
 #define KSERVICE_DEPRECATED_VERSION_5(minor, text)      KSERVICE_DEPRECATED_VERSION_5_##minor(text)
 #define KSERVICE_DEPRECATED_VERSION(major, minor, text) KSERVICE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KSERVICE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KSERVICE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KSERVICE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KSERVICE_DEPRECATED_VERSION(major, minor, text)
+#  define KSERVICE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KSERVICE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KSERVICE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KSERVICE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KSERVICE_EXPORT_H */
